yakumo.cinder.v2.volume_backup.Manager

Package yakumo :: Package cinder :: Package v2 :: Module volume_backup :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for volume backups on Block Storage V2 API

Nested Classes | [hide private]
| resource_class resource class for volume backups on Block Storage V2 API

Instance Methods | [hide private]
yakumo.cinder.v2.snapshot.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, source_volume=`'``__UNDEF__``'`, container=`'``__UNDEF__``'`, is_incremental=`'``__UNDEF__``'`) Create a backup of a volume | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``volume``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``backup``'``
| _json_resources_key = ``'``backups``'``
| _hidden_methods = ``[``'``update``'``]``
| _url_resource_list_path = ``'``/backups/detail``'``
| _url_resource_path = ``'``/backups``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, source_volume=`'``__UNDEF__``'`, container=`'``__UNDEF__``'`, is_incremental=`'``__UNDEF__``'`) | source code
Create a backup of a volume Parameters: `name` (str) - Snapshot name `description` (str) - Description `source_volume` (yakumo.cinder.v2.volume.Resource) - Source volume `container` - Container for store a volume backup `is_incremental` (bool) - Whether the backup is incremental Returns: yakumo.cinder.v2.snapshot.Resource Created volume object Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'display_name', mapper.Noop), ('d
      escription', 'description', mapper.Noop), ('availability_zone', 'avail
      ability_zone', mapper.Resource('availability_zone')), ('source_volume'
      , 'volume_id', mapper.Resource('cinder.volume')), ('size', 'size', map
      per.Noop), ('object_count', 'object_count', mapper.Noop), ('container'
      , 'container', mapper.Noop), ('created_at', 'created_at', mapper.DateT
      ime), ('updated_at', 'updated_at', mapper.DateTime), ('status', 'statu
      s', mapper.Noop), ('fail_reason', 'fail_reason', mapper.Noop), ('has_d
      ...